@@ -1,21 +1,8 @@
 /*
-    Copyright 2006-2008 by Robert Knight <robertknight@gmail.com>
-    Copyright 2009 by Thomas Dreibholz <dreibh@iem.uni-due.de>
+    SPDX-FileCopyrightText: 2006-2008 Robert Knight <robertknight@gmail.com>
+    SPDX-FileCopyrightText: 2009 Thomas Dreibholz <dreibh@iem.uni-due.de>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301  USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "SaveHistoryTask.h"
@@ -33,8 +20,8 @@
 #include "session/SessionManager.h"
 #include "Emulation.h"
 
-#include "PlainTextDecoder.h"
-#include "HTMLDecoder.h"
+#include "../decoders/PlainTextDecoder.h"
+#include "../decoders/HTMLDecoder.h"
 
 namespace Konsole {
 
@@ -126,7 +113,7 @@ void SaveHistoryTask::execute()
         if (((dialog->selectedNameFilter()).contains(QLatin1String("html"), Qt::CaseInsensitive)) ||
            ((dialog->selectedFiles()).at(0).endsWith(QLatin1String("html"), Qt::CaseInsensitive))) {
             Profile::Ptr profile = SessionManager::instance()->sessionProfile(session);
-            jobInfo.decoder = new HTMLDecoder(profile);
+            jobInfo.decoder = new HTMLDecoder(profile->colorScheme(), profile->font());
         } else {
             jobInfo.decoder = new PlainTextDecoder();
         }
@@ -185,7 +172,7 @@ void SaveHistoryTask::jobResult(KJob* job)
     delete decoder;
 
     // notify the world that the task is done
-    emit completed(true);
+    Q_EMIT completed(true);
 
     if (autoDelete()) {
         deleteLater();
