@@ -1,23 +1,8 @@
 /*
-    This file is part of Konsole, KDE's terminal.
+    SPDX-FileCopyrightText: 2007-2008 Robert Knight <robertknight@gmail.com>
+    SPDX-FileCopyrightText: 1997, 1998 Lars Doelle <lars.doelle@on-line.de>
 
-    Copyright 2007-2008 by Robert Knight <robertknight@gmail.com>
-    Copyright 1997,1998 by Lars Doelle <lars.doelle@on-line.de>
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301  USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef SCREEN_H
@@ -40,7 +25,8 @@
 #define MODE_Screen    3
 #define MODE_Cursor    4
 #define MODE_NewLine   5
-#define MODES_SCREEN   6
+#define MODE_AppScreen 6
+#define MODES_SCREEN   7
 
 namespace Konsole {
 class TerminalCharacterDecoder;
@@ -603,6 +589,13 @@ public:
 
     static const Character DefaultChar;
 
+    // Return the total number of lines before resize (fix scroll glitch)
+    int getOldTotalLines();
+    // Return if it was a resize signal (fix scroll glitch)
+    bool isResize();
+    // Set reflow condition
+    void setReflowLines(bool enable);
+
 private:
     //copies a line of text from the screen or history into a stream using a
     //specified character decoder.  Returns the number of lines actually copied,
@@ -638,6 +631,8 @@ private:
     TerminalDisplay *_currentTerminalDisplay;
 
     void addHistLine();
+    // add lines from _screen to _history and remove from _screen the added lines (used to resize lines and columns)
+    void fastAddHistLine();
 
     void initTabStops();
 
@@ -661,6 +656,11 @@ private:
     // should be as minimal as possible
     static Character *getCharacterBuffer(const int size);
 
+    // Get the cursor line after checking if its app mode or not
+    int getCursorLine();
+    // Set the cursor line after checking if its app mode or not
+    void setCursorLine (int newLine);
+
     int getLineLength(const int line) const;
 
     // screen image ----------------
@@ -668,7 +668,7 @@ private:
     int _columns;
 
     typedef QVector<Character> ImageLine;      // [0..columns]
-    ImageLine *_screenLines;             // [lines]
+    QVector<ImageLine> _screenLines;             // [lines]
     int _screenLinesSize;                // _screenLines.size()
 
     int _scrolledLines;
@@ -676,6 +676,10 @@ private:
 
     int _droppedLines;
 
+    int _oldTotalLines;
+    bool _isResize;
+    bool _enableReflowLines;
+
     QVarLengthArray<LineProperty, 64> _lineProperties;
 
     // history buffer ---------------
@@ -740,6 +744,9 @@ private:
     quint32 _lastDrawnChar;
     EscapeSequenceUrlExtractor *_escapeSequenceUrlExtractor;
     void toggleUrlInput();
+
+    // Vt102Emulation defined max argument value that can be passed to a Screen function
+    const int MAX_SCREEN_ARGUMENT = 40960; 
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(Screen::DecodingOptions)
