@@ -1,20 +1,7 @@
 /*
-    Copyright 2006-2008 by Robert Knight <robertknight@gmail.com>
+    SPDX-FileCopyrightText: 2006-2008 Robert Knight <robertknight@gmail.com>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301  USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 // Own
@@ -117,26 +104,26 @@ void ViewManager::setupActions()
     action->setText(i18nc("@action:inmenu", "Split View Left/Right"));
     connect(action, &QAction::triggered, this, &ViewManager::splitLeftRight);
     collection->addAction(QStringLiteral("split-view-left-right"), action);
-    collection->setDefaultShortcut(action, Konsole::ACCEL + Qt::Key_ParenLeft);
+    collection->setDefaultShortcut(action, Konsole::ACCEL | Qt::Key_ParenLeft);
 
     action = new QAction(this);
     action->setIcon(QIcon::fromTheme(QStringLiteral("view-split-top-bottom")));
     action->setText(i18nc("@action:inmenu", "Split View Top/Bottom"));
     connect(action, &QAction::triggered, this, &ViewManager::splitTopBottom);
-    collection->setDefaultShortcut(action, Konsole::ACCEL + Qt::Key_ParenRight);
+    collection->setDefaultShortcut(action, Konsole::ACCEL | Qt::Key_ParenRight);
     collection->addAction(QStringLiteral("split-view-top-bottom"), action);
 
     action = new QAction(this);
     action->setText(i18nc("@action:inmenu", "Expand View"));
     action->setEnabled(false);
     connect(action, &QAction::triggered, this, &ViewManager::expandActiveContainer);
-    collection->setDefaultShortcut(action, Konsole::ACCEL + Qt::SHIFT + Qt::Key_BracketRight);
+    collection->setDefaultShortcut(action, Konsole::ACCEL | Qt::SHIFT | Qt::Key_BracketRight);
     collection->addAction(QStringLiteral("expand-active-view"), action);
     _multiSplitterOnlyActions << action;
 
     action = new QAction(this);
     action->setText(i18nc("@action:inmenu", "Shrink View"));
-    collection->setDefaultShortcut(action, Konsole::ACCEL + Qt::SHIFT + Qt::Key_BracketLeft);
+    collection->setDefaultShortcut(action, Konsole::ACCEL | Qt::SHIFT | Qt::Key_BracketLeft);
     action->setEnabled(false);
     collection->addAction(QStringLiteral("shrink-active-view"), action);
     connect(action, &QAction::triggered, this, &ViewManager::shrinkActiveContainer);
@@ -152,7 +139,7 @@ void ViewManager::setupActions()
 
     // Ctrl+Shift+D is not used as a shortcut by default because it is too close
     // to Ctrl+D - which will terminate the session in many cases
-    collection->setDefaultShortcut(action, Konsole::ACCEL + Qt::SHIFT + Qt::Key_H);
+    collection->setDefaultShortcut(action, Konsole::ACCEL | Qt::SHIFT | Qt::Key_H);
 
     action = collection->addAction(QStringLiteral("detach-tab"));
     action->setEnabled(true);
@@ -163,7 +150,7 @@ void ViewManager::setupActions()
 
     // keyboard shortcut only actions
     action = new QAction(i18nc("@action Shortcut entry", "Next Tab"), this);
-    const QList<QKeySequence> nextViewActionKeys{Qt::SHIFT + Qt::Key_Right, Qt::CTRL + Qt::Key_PageDown};
+    const QList<QKeySequence> nextViewActionKeys{Qt::SHIFT | Qt::Key_Right, Qt::CTRL | Qt::Key_PageDown};
     collection->setDefaultShortcuts(action, nextViewActionKeys);
     collection->addAction(QStringLiteral("next-tab"), action);
     connect(action, &QAction::triggered, this, &ViewManager::nextView);
@@ -171,7 +158,7 @@ void ViewManager::setupActions()
     // _viewSplitter->addAction(nextViewAction);
 
     action = new QAction(i18nc("@action Shortcut entry", "Previous Tab"), this);
-    const QList<QKeySequence> previousViewActionKeys{Qt::SHIFT + Qt::Key_Left, Qt::CTRL + Qt::Key_PageUp};
+    const QList<QKeySequence> previousViewActionKeys{Qt::SHIFT | Qt::Key_Left, Qt::CTRL | Qt::Key_PageUp};
     collection->setDefaultShortcuts(action, previousViewActionKeys);
     collection->addAction(QStringLiteral("previous-tab"), action);
     connect(action, &QAction::triggered, this, &ViewManager::previousView);
@@ -181,25 +168,25 @@ void ViewManager::setupActions()
     action = new QAction(i18nc("@action Shortcut entry", "Focus Above Terminal"), this);
     connect(action, &QAction::triggered, this, &ViewManager::focusUp);
     collection->addAction(QStringLiteral("focus-view-above"), action);
-    collection->setDefaultShortcut(action, Qt::SHIFT + Qt::CTRL + Qt::Key_Up);
+    collection->setDefaultShortcut(action, Qt::SHIFT | Qt::CTRL | Qt::Key_Up);
     _viewContainer->addAction(action);
     _multiSplitterOnlyActions << action;
 
     action = new QAction(i18nc("@action Shortcut entry", "Focus Below Terminal"), this);
-    collection->setDefaultShortcut(action, Qt::SHIFT + Qt::CTRL + Qt::Key_Down);
+    collection->setDefaultShortcut(action, Qt::SHIFT | Qt::CTRL | Qt::Key_Down);
     collection->addAction(QStringLiteral("focus-view-below"), action);
     connect(action, &QAction::triggered, this, &ViewManager::focusDown);
     _multiSplitterOnlyActions << action;
     _viewContainer->addAction(action);
 
     action = new QAction(i18nc("@action Shortcut entry", "Focus Left Terminal"), this);
-    collection->setDefaultShortcut(action, Konsole::ACCEL + Qt::SHIFT + Konsole::LEFT);
+    collection->setDefaultShortcut(action, Konsole::ACCEL | Qt::SHIFT | Konsole::LEFT);
     connect(action, &QAction::triggered, this, &ViewManager::focusLeft);
     collection->addAction(QStringLiteral("focus-view-left"), action);
     _multiSplitterOnlyActions << action;
 
     action = new QAction(i18nc("@action Shortcut entry", "Focus Right Terminal"), this);
-    collection->setDefaultShortcut(action, Konsole::ACCEL + Qt::SHIFT + Konsole::RIGHT);
+    collection->setDefaultShortcut(action, Konsole::ACCEL | Qt::SHIFT | Konsole::RIGHT);
     connect(action, &QAction::triggered, this, &ViewManager::focusRight);
     collection->addAction(QStringLiteral("focus-view-right"), action);
     _multiSplitterOnlyActions << action;
@@ -211,7 +198,7 @@ void ViewManager::setupActions()
 
     action = new QAction(i18nc("@action Shortcut entry", "Last Used Tabs"), this);
     connect(action, &QAction::triggered, this, &ViewManager::lastUsedView);
-    collection->setDefaultShortcut(action, Qt::CTRL + Qt::Key_Tab);
+    collection->setDefaultShortcut(action, Qt::CTRL | Qt::Key_Tab);
     collection->addAction(QStringLiteral("last-used-tab"), action);
 
     action = new QAction(i18nc("@action Shortcut entry", "Toggle Between Two Tabs"), this);
@@ -221,28 +208,28 @@ void ViewManager::setupActions()
 
     action = new QAction(i18nc("@action Shortcut entry", "Last Used Tabs (Reverse)"), this);
     collection->addAction(QStringLiteral("last-used-tab-reverse"), action);
-    collection->setDefaultShortcut(action, Qt::CTRL + Qt::SHIFT + Qt::Key_Tab);
+    collection->setDefaultShortcut(action, Qt::CTRL | Qt::SHIFT | Qt::Key_Tab);
     connect(action, &QAction::triggered, this, &ViewManager::lastUsedViewReverse);
 
     action = new QAction(i18nc("@action Shortcut entry", "Toggle maximize current view"), this);
     action->setText(i18nc("@action:inmenu", "Toggle maximize current view"));
     action->setIcon(QIcon::fromTheme(QStringLiteral("view-fullscreen")));
     collection->addAction(QStringLiteral("toggle-maximize-current-view"), action);
-    collection->setDefaultShortcut(action, Qt::CTRL + Qt::SHIFT + Qt::Key_E);
+    collection->setDefaultShortcut(action, Qt::CTRL | Qt::SHIFT | Qt::Key_E);
     connect(action, &QAction::triggered, _viewContainer, &TabbedViewContainer::toggleMaximizeCurrentTerminal);
     _multiSplitterOnlyActions << action;
     _viewContainer->addAction(action);
 
     action = new QAction(i18nc("@action Shortcut entry", "Move tab to the right"), this);
     collection->addAction(QStringLiteral("move-tab-to-right"), action);
-    collection->setDefaultShortcut(action, Qt::CTRL + Qt::ALT + Qt::Key_Right);
+    collection->setDefaultShortcut(action, Qt::CTRL | Qt::ALT | Qt::Key_Right);
     connect(action, &QAction::triggered, _viewContainer, &TabbedViewContainer::moveTabRight);
     _multiTabOnlyActions << action;
     _viewContainer->addAction(action);
 
     action = new QAction(i18nc("@action Shortcut entry", "Move tab to the left"), this);
     collection->addAction(QStringLiteral("move-tab-to-left"), action);
-    collection->setDefaultShortcut(action, Qt::CTRL + Qt::ALT + Qt::Key_Left);
+    collection->setDefaultShortcut(action, Qt::CTRL | Qt::ALT | Qt::Key_Left);
     connect(action, &QAction::triggered, _viewContainer, &TabbedViewContainer::moveTabLeft);
     _multiTabOnlyActions << action;
     _viewContainer->addAction(action);
@@ -260,12 +247,11 @@ void ViewManager::setupActions()
             collection->setDefaultShortcut(action, QStringLiteral("Alt+%1").arg(i + 1));
         } else if (i == 9) {
             // add shortcut for 10th tab
-            collection->setDefaultShortcut(action, Qt::ALT + Qt::Key_0);
+            collection->setDefaultShortcut(action, Qt::ALT | Qt::Key_0);
         }
     }
 
     connect(_viewContainer, &TabbedViewContainer::viewAdded, this, &ViewManager::toggleActionsBasedOnState);
-    connect(_viewContainer, &TabbedViewContainer::viewRemoved, this, &ViewManager::toggleActionsBasedOnState);
     connect(_viewContainer, &QTabWidget::currentChanged, this, &ViewManager::toggleActionsBasedOnState);
 
     toggleActionsBasedOnState();
@@ -412,7 +398,7 @@ void ViewManager::detachActiveView()
         auto newSplitter = new ViewSplitter();
         newSplitter->addTerminalDisplay(terminal, Qt::Horizontal);
         QHash<TerminalDisplay*, Session*> detachedSessions = forgetAll(newSplitter);
-        emit terminalsDetached(newSplitter, detachedSessions);
+        Q_EMIT terminalsDetached(newSplitter, detachedSessions);
         focusAnotherTerminal(activeSplitter->getToplevelSplitter());
         toggleActionsBasedOnState();
     }
@@ -428,7 +414,7 @@ void ViewManager::detachTab(int tabIdx)
 {
     ViewSplitter* splitter = _viewContainer->viewSplitterAt(tabIdx);
     QHash<TerminalDisplay*, Session*> detachedSessions = forgetAll(_viewContainer->viewSplitterAt(tabIdx));
-    emit terminalsDetached(splitter, detachedSessions);
+    Q_EMIT terminalsDetached(splitter, detachedSessions);
 }
 
 QHash<TerminalDisplay*, Session*> ViewManager::forgetAll(ViewSplitter* splitter) {
@@ -444,7 +430,7 @@ QHash<TerminalDisplay*, Session*> ViewManager::forgetAll(ViewSplitter* splitter)
 
 Session* ViewManager::forgetTerminal(TerminalDisplay* terminal)
 {
-    disconnect(terminal, &TerminalDisplay::requestToggleExpansion, nullptr, nullptr);
+    unregisterTerminal(terminal);
 
     removeController(terminal->sessionController());
     auto session = _sessionMap.take(terminal);
@@ -495,7 +481,7 @@ void ViewManager::sessionFinished()
 
     toplevelSplitter->handleMinimizeMaximize(false);
     view->deleteLater();
-
+    connect(view, &QObject::destroyed, this, [this]() { toggleActionsBasedOnState(); });
 
     // Only remove the controller from factory() if it's actually controlling
     // the session from the sender.
@@ -503,13 +489,12 @@ void ViewManager::sessionFinished()
     if ((!_pluggedController.isNull()) && (_pluggedController->session() == session)) {
         // This is needed to remove this controller from factory() in
         // order to prevent BUG: 185466 - disappearing menu popup
-        emit unplugController(_pluggedController);
+        Q_EMIT unplugController(_pluggedController);
     }
 
     if (!_sessionMap.empty()) {
         updateTerminalDisplayHistory(view, true);
         focusAnotherTerminal(toplevelSplitter);
-        toggleActionsBasedOnState();
     }
 }
 
@@ -635,7 +620,7 @@ void ViewManager::controllerChanged(SessionController *controller)
     updateTerminalDisplayHistory(controller->view());
 
     _pluggedController = controller;
-    emit activeViewChanged(controller);
+    Q_EMIT activeViewChanged(controller);
 }
 
 SessionController *ViewManager::activeViewController() const
@@ -649,11 +634,10 @@ void ViewManager::attachView(TerminalDisplay *terminal, Session *session)
             Qt::UniqueConnection);
 
     // Disconnect from the other viewcontainer.
-    disconnect(terminal, &TerminalDisplay::requestToggleExpansion, nullptr, nullptr);
+    unregisterTerminal(terminal);
 
     // reconnect on this container.
-    connect(terminal, &TerminalDisplay::requestToggleExpansion,
-            _viewContainer, &TabbedViewContainer::toggleMaximizeCurrentTerminal, Qt::UniqueConnection);
+    registerTerminal(terminal);
 
     _sessionMap[terminal] = session;
     createController(session, terminal);
@@ -703,7 +687,6 @@ TabbedViewContainer *ViewManager::createContainer()
            [this, container]() {
                containerViewsChanged(container);
            });
-
     connect(container, &Konsole::TabbedViewContainer::viewRemoved, this,
            [this, container]() {
                containerViewsChanged(container);
@@ -713,8 +696,6 @@ TabbedViewContainer *ViewManager::createContainer()
             this, &ViewManager::newViewRequest);
     connect(container, &Konsole::TabbedViewContainer::newViewWithProfileRequest,
             this, &Konsole::ViewManager::newViewWithProfileRequest);
-    connect(container, &Konsole::TabbedViewContainer::viewRemoved, this,
-            &Konsole::ViewManager::viewDestroyed);
     connect(container, &Konsole::TabbedViewContainer::activeViewChanged, this,
             &Konsole::ViewManager::activateView);
 
@@ -770,7 +751,7 @@ void ViewManager::containerViewsChanged(TabbedViewContainer *container)
 {
     Q_UNUSED(container)
     // TODO: Verify that this is right.
-    emit viewPropertiesChanged(viewProperties());
+    Q_EMIT viewPropertiesChanged(viewProperties());
 }
 
 void ViewManager::viewDestroyed(QWidget *view)
@@ -796,15 +777,14 @@ void ViewManager::viewDestroyed(QWidget *view)
     // The below causes the menus  to be messed up
     // Only happens when using the tab bar close button
 //    if (_pluggedController)
-//        emit unplugController(_pluggedController);
+//        Q_EMIT unplugController(_pluggedController);
 }
 
 TerminalDisplay *ViewManager::createTerminalDisplay(Session *session)
 {
     auto display = new TerminalDisplay(nullptr);
     display->setRandomSeed(session->sessionId() | (qApp->applicationPid() << 10));
-    connect(display, &TerminalDisplay::requestToggleExpansion,
-            _viewContainer, &TabbedViewContainer::toggleMaximizeCurrentTerminal);
+    registerTerminal(display);
 
     return display;
 }
@@ -830,8 +810,8 @@ void ViewManager::applyProfileToView(TerminalDisplay *view, const Profile::Ptr &
 {
     Q_ASSERT(profile);
     view->applyProfile(profile);
-    emit updateWindowIcon();
-    emit blurSettingChanged(view->colorScheme()->blur());
+    Q_EMIT updateWindowIcon();
+    Q_EMIT blurSettingChanged(view->colorScheme()->blur());
 }
 
 void ViewManager::updateViewsForSession(Session *session)
@@ -1173,3 +1153,17 @@ void ViewManager::updateTerminalDisplayHistory(TerminalDisplay* terminalDisplay,
         }
     }
 }
+
+void ViewManager::registerTerminal(TerminalDisplay *terminal)
+{
+    connect(terminal, &TerminalDisplay::requestToggleExpansion,
+            _viewContainer, &TabbedViewContainer::toggleMaximizeCurrentTerminal, Qt::UniqueConnection);
+    connect(terminal, &TerminalDisplay::requestMoveToNewTab,
+            _viewContainer, &TabbedViewContainer::moveToNewTab, Qt::UniqueConnection);
+}
+
+void ViewManager::unregisterTerminal(TerminalDisplay *terminal)
+{
+    disconnect(terminal, &TerminalDisplay::requestToggleExpansion, nullptr, nullptr);
+    disconnect(terminal, &TerminalDisplay::requestMoveToNewTab, nullptr, nullptr);
+}
