@@ -1,22 +1,9 @@
 /*
     This file is part of Konsole, a terminal emulator for KDE.
 
-    Copyright 2018 by Mariusz Glebocki <mglb@arccos-1.net>
+    SPDX-FileCopyrightText: 2018 Mariusz Glebocki <mglb@arccos-1.net>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301  USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include <QCommandLineParser>
@@ -83,8 +70,7 @@ protected:
             //          "udRangeInd" (UnicodeData.txt only) - if present, the line is either first or last line of a range
             R"#([ \t]*(?<field0>[^#;\n]*?(?:, (?<udRangeInd>First|Last)>)?)[ \t]*(?:;|(?:\#.*)?$))|)#"
             // Match 2..n: "field" - n-th field
-            R"#((?:\G(?<=;)[ \t]*(?<field>[^#;\n]*?)[ \t]*(?:;|(?:#.*)?$)))#"),
-            QRegularExpression::OptimizeOnFirstUsageOption
+            R"#((?:\G(?<=;)[ \t]*(?<field>[^#;\n]*?)[ \t]*(?:;|(?:#.*)?$)))#")
         );
         static const QRegularExpression UD_RANGE_IND_RE(QStringLiteral(", (First|Last)"));
         static const QRegularExpression COMMENT_RE(QStringLiteral("^[ \t]*(#.*)?$"));
@@ -730,7 +716,7 @@ bool details(QTextStream &out, const QVector<CharacterProperties> &props, const
 template <class EntryType>
 static void processInputFiles(QVector<CharacterProperties> &props, const QStringList &files, const QString &fileTypeName,
                               void (*cb)(CharacterProperties &prop, const EntryType &entry)) {
-    static const QRegularExpression PROTOCOL_RE(QStringLiteral(R"#(^[a-z]+://)#"), QRegularExpression::OptimizeOnFirstUsageOption);
+    static const QRegularExpression PROTOCOL_RE(QStringLiteral(R"#(^[a-z]+://)#"));
     for(const QString &fileName: files) {
         qInfo().noquote() << QStringLiteral("Parsing as %1: %2").arg(fileTypeName).arg(fileName);
         QSharedPointer<QIODevice> source = nullptr;
